"""
Popular Quotes Database
"""

from __future__ import absolute_import

import pkg_resources

import pmxbot.quotes as quotes


def open():
	db_file = pkg_resources.resource_filename('popquotes', 'popquotes.sqlite')
	return quotes.SQLiteQuotes.from_URI('sqlite:' + db_file)



from __future__ import absolute_import, unicode_literals

import itertools

from pmxbot.core import command

import popquotes


def bartletts(lib, nick, qsearch):
	qs = popquotes.open()
	qs.lib = lib
	qsearch = qsearch.strip()
	if nick == 'pmxbot':
		qt, i, n = qs.quoteLookup()
		if not qt:
			return
		if qt.find(':', 0, 15) > -1:
			qt = qt.split(':', 1)[1].strip()
	else:
		qt, i, n = qs.lookup_with_num(qsearch)
		if not qt:
			return
		qt = '(%s/%s): %s' % (i, n, qt)
	return qt


# declare all of the popquotes commands
quote_libs = (
	# name, aliases, doc, lib
	('bender', ('bend',),
		'Quote Bender, a la http://en.wikiquote.org/wiki/Futurama', 'bender'),
	('zoidberg', ('zoid',),
		'Quote Zoidberg, a la http://en.wikiquote.org/wiki/Futurama', 'zoid'),
	('simpsons', ('simp',), 'Quote the Simpsons, a la http://snpp.com/',
		'simpsons'),
	('hal', ('2001',), 'HAL 9000', 'hal'),
	('grail', (), 'I questing baby', 'grail'),
	('anchorman', (), 'Quote Anchorman.', 'anchorman'),
	('hangover', (), 'Quote hangover.', 'hangover'),
	('R', ('r',), 'Quote the R mailing list', 'R'),
)


# create the popquotes commands per the declarations above
def make_command(name, aliases, doc, lib):
	# create a command function with the pmxbot command signature
	def cmd_func(client, event, channel, nick, rest):
		return bartletts(lib, nick, rest)
	# register the new func as a command
	pmxbot_cmd = command(name, aliases=aliases, doc=doc)(cmd_func)
	# add the command to the global namespace so it can be tested
	globals()[name] = pmxbot_cmd


def install_commands():
	list(itertools.starmap(make_command, quote_libs))



import re
import operator

import pmxbot.core

import popquotes.pmxbot


def setup_module(request):
	popquotes.pmxbot.install_commands()


def test_bender():
	quote_pattern = re.compile('\(\d+/\d+\): .+')
	res = popquotes.pmxbot.bartletts('bender', 'somenick', '')
	assert res is not None
	assert quote_pattern.match(res)


def test_registered():
	handlers = pmxbot.core.Handler._registry
	all_names = map(operator.attrgetter('name'), handlers)
	assert 'bender' in all_names
